@@ -1,41 +1,6 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-"""
-Created on Fri Apr 10 14:12:56 2020
 
-@author: Peter Corke
-"""
-
-# This file is part of the SpatialMath toolbox for Python
-# https://github.com/petercorke/spatialmath-python
-# 
-# MIT License
-# 
-# Copyright (c) 1993-2020 Peter Corke
-# 
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-# 
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-# 
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-
-# Contributors:
-# 
-#     1. Luis Fernando Lara Tobar and Peter Corke, 2008
-#     2. Josh Carrigg Hodson, Aditya Dua, Chee Ho Chan, 2017 (robopy)
-#     3. Peter Corke, 2020
+# pylint: disable=invalid-name
 
 import sys
 import math
@@ -128,7 +93,7 @@ def isunit(q, tol=10):
 
     :seealso: unit
     """
-    return tr.iszerovec(q)
+    return tr.iszerovec(q, tol=tol)
 
 
 def isequal(q1, q2, tol=100, unitq=False):
@@ -155,10 +120,10 @@ def isequal(q1, q2, tol=100, unitq=False):
     q1 = argcheck.getvector(q1, 4)
     q2 = argcheck.getvector(q2, 4)
 
-    if unit:
+    if unitq:
         return (np.sum(np.abs(q1 - q2)) < tol * _eps) or (np.sum(np.abs(q1 + q2)) < tol * _eps)
     else:
-        return (np.sum(np.abs(q1 - q2)) < tol * _eps)
+        return np.sum(np.abs(q1 - q2)) < tol * _eps
 
 
 def q2v(q):
@@ -302,7 +267,7 @@ def vvmul(qa, qb):
     return np.r_[qa[1] * qb[2] - qb[1] * qa[2] + qb[0] * t6 + qa[0] * t11, -qa[0] * qb[2] + qb[0] * qa[2] + qb[1] * t6 + qa[1] * t11, qa[0] * qb[1] - qb[0] * qa[1] + qb[2] * t6 + qa[2] * t11]
 
 
-def pow(q, power):
+def qpow(q, power):
     """
     Raise quaternion to a power
 
@@ -324,7 +289,7 @@ def pow(q, power):
     q = argcheck.getvector(q, 4)
     assert isinstance(power, int), "Power must be an integer"
     qr = eye()
-    for i in range(0, abs(power)):
+    for _ in range(0, abs(power)):
         qr = qqmul(qr, q)
 
     if power < 0:
@@ -375,12 +340,16 @@ def q2r(q):
                      [2 * (x * z - s * y), 2 * (y * z + s * x), 1 - 2 * (x ** 2 + y ** 2)]])
 
 
-def r2q(R, check=True):
+def r2q(R, check=False, tol=100):
     """
     Convert SO(3) rotation matrix to unit-quaternion
 
     :arg R: rotation matrix
     :type R: numpy.ndarray, shape=(3,3)
+    :param check: check validity of rotation matrix, default False
+    :type check: bool
+    :param tol: tolerance in units of eps
+    :type tol: float
     :return: unit-quaternion
     :rtype: numpy.ndarray, shape=(3,)
 
@@ -392,7 +361,10 @@ def r2q(R, check=True):
 
     """
     assert R.shape == (3, 3) and tr.isR(R), "Argument must be 3x3 rotation matrix"
-    qs = math.sqrt(np.trace(R) + 1) / 2.0
+    if check:
+        assert tr.isR(R, tol=tol), "Argument must be a valid SO(3) matrix"
+
+    qs = math.sqrt(max(0, np.trace(R) + 1)) / 2.0
     kx = R[2, 1] - R[1, 2]  # Oz - Ay
     ky = R[0, 2] - R[2, 0]  # Ax - Nz
     kz = R[1, 0] - R[0, 1]  # Ny - Ox
@@ -424,7 +396,7 @@ def r2q(R, check=True):
 
     kv = np.r_[kx, ky, kz]
     nm = np.linalg.norm(kv)
-    if abs(nm) < 100 * _eps:
+    if abs(nm) < tol * _eps:
         return eye()
     else:
         return np.r_[qs, (math.sqrt(1.0 - qs ** 2) / nm) * kv]
@@ -460,25 +432,25 @@ def slerp(q0, q1, s, shortest=False):
     assert 0 <= s <= 1, 's must be in the interval [0,1]'
     q0 = argcheck.getvector(q0, 4)
     q1 = argcheck.getvector(q1, 4)
-    
+
     if s == 0:
         return q0
     elif s == 1:
         return q1
 
-    dot = np.dot(q0, q1)
+    dotprod = np.dot(q0, q1)
 
     # If the dot product is negative, the quaternions
     # have opposite handed-ness and slerp won't take
     # the shorter path. Fix by reversing one quaternion.
     if shortest:
-        if dot < 0:
-            q0 = - q0
-            dot = -dot
+        if dotprod < 0:
+            q0 = -q0   # pylint: disable=invalid-unary-operand-type
+            dotprod = -dotprod # pylint: disable=invalid-unary-operand-type
 
-    dot = np.clip(dot, -1, 1)  # Clip within domain of acos()
-    theta = math.acos(dot)  # theta is the angle between rotation vectors
-    if abs(theta) > 10*_eps:
+    dotprod = np.clip(dotprod, -1, 1)  # Clip within domain of acos()
+    theta = math.acos(dotprod)  # theta is the angle between rotation vectors
+    if abs(theta) > 10 * _eps:
         s0 = math.sin((1 - s) * theta)
         s1 = math.sin(s * theta)
         return ((q0 * s0) + (q1 * s1)) / math.sin(theta)
@@ -567,7 +539,7 @@ def dotb(q, w):
     :return: rate of change of unit quaternion
     :rtype: numpy.ndarray, shape=(4,)
 
-    ``dot(q, w)`` is the rate of change of the elements of the unit quaternion ``q``
+    ``dotb(q, w)`` is the rate of change of the elements of the unit quaternion ``q``
     which represents the orientation of a body frame with angular velocity ``w`` in
     the body frame.
 
@@ -605,7 +577,7 @@ def angle(q1, q2):
 
     q1 = argcheck.getvector(q1, 4)
     q2 = argcheck.getvector(q2, 4)
-    return 2.0 * math.atan2(norm(q1 - q2), norm(q1 + q2))
+    return 2.0 * math.atan2(tr.norm(q1 - q2), tr.norm(q1 + q2))
 
 
 def qprint(q, delim=('<', '>'), fmt='%f', file=sys.stdout):
@@ -646,6 +618,5 @@ def qprint(q, delim=('<', '>'), fmt='%f', file=sys.stdout):
 
 if __name__ == '__main__':  # pragma: no cover
     import pathlib
-    import os.path
 
-    exec(open(os.path.join(pathlib.Path(__file__).parent.absolute(), "test_quaternions.py")).read())
+    exec(open(pathlib.Path(__file__).parent.absolute() / "test_quaternions.py").read())  # pylint: disable=exec-used
