@@ -1,25 +1,47 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
+"""
+Classes to abstract 3D pose and orientation using matrices in SE(3) and SO(3)
+
+To use::
+
+    from spatialmath.pose3d import *
+    T = SE3.Rx(0.3)
+
+    import spatialmath as sm
+    T = sm.SE3.Rx(0.3)
+
+
+ .. inheritance-diagram:: spatialmath.pose3d
+    :top-classes: collections.UserList
+    :parts: 1
+"""
+
+# pylint: disable=invalid-name
 
-from collections import UserList
 import numpy as np
-import math
 
 from spatialmath.base import argcheck
 from spatialmath import base as tr
-from spatialmath import super_pose as sp
+# from spatialmath import Twist
+from spatialmath.super_pose import SMPose
+import spatialmath as sm
+
 
 # ============================== SO3 =====================================#
 
-class SO3(sp.SMPose):
+
+class SO3(SMPose):
     """
     SO(3) subclass
 
-    This subclass represents rotations in 3D space.  Internally it is a 3x3 orthogonal matrix belonging
-    to the group SO(3).
+    This subclass represents rotations in 3D space.  Internally it is a 3x3 
+    orthogonal matrix belonging to the group SO(3).
 
-    .. inheritance-diagram::
+ .. inheritance-diagram:: spatialmath.pose3d.SO3
+    :top-classes: collections.UserList
+    :parts: 1
     """
 
     def __init__(self, arg=None, *, check=True):
@@ -40,12 +62,21 @@ class SO3(sp.SMPose):
 
         if arg is None:
             # empty constructor
-            if type(self) is SO3:
+            if isinstance(self, SO3):
                 self.data = [np.eye(3)]  # identity rotation
         else:
-            super()._arghandler(arg, check=check)
+            super().arghandler(arg, check=check)
 
 # ------------------------------------------------------------------------ #
+    @property
+    def shape(self):
+        """
+        Shape of the object's interal matrix representation
+
+        :return: (3,3)
+        :rtype: tuple
+        """
+        return (3, 3)
 
     @property
     def R(self):
@@ -56,7 +87,7 @@ class SO3(sp.SMPose):
         :rtype: numpy.ndarray, shape=(3,3)
 
         ``x.R`` returns the rotation matrix, when `x` is `SO3` or `SE3`. If `len(x)` is:
-            
+
         - 1, return an ndarray with shape=(3,3)
         - N>1, return ndarray with shape=(N,3,3)
         """
@@ -122,9 +153,8 @@ class SO3(sp.SMPose):
         else:
             return SO3([x.T for x in self.A])
 
-
     def eul(self, unit='deg'):
-        """
+        r"""
         SO(3) or SE(3) as Euler angles
 
         :param unit: angular units: 'rad' [default], or 'deg'
@@ -137,7 +167,7 @@ class SO3(sp.SMPose):
         rotations about the Z, Y, Z axes respectively.
 
         If `len(x)` is:
-            
+
         - 1, return an ndarray with shape=(3,)
         - N>1, return ndarray with shape=(N,3)
 
@@ -170,40 +200,70 @@ class SO3(sp.SMPose):
               then by roll about the new x-axis.  Convention for a mobile robot with x-axis forward
               and y-axis sideways.
             - 'xyz', rotate by yaw about the x-axis, then by pitch about the new y-axis,
-              then by roll about the new z-axis. Covention for a robot gripper with z-axis forward
+              then by roll about the new z-axis. Convention for a robot gripper with z-axis forward
               and y-axis between the gripper fingers.
             - 'yxz', rotate by yaw about the y-axis, then by pitch about the new x-axis,
               then by roll about the new z-axis. Convention for a camera with z-axis parallel
               to the optic axis and x-axis parallel to the pixel rows.
 
         If `len(x)` is:
-            
+
         - 1, return an ndarray with shape=(3,)
         - N>1, return ndarray with shape=(N,3)
 
         :seealso: :func:`~spatialmath.pose3d.SE3.RPY`, ::func:`spatialmath.base.transforms3d.tr2rpy`
         """
         if len(self) == 1:
-            return tr.tr2rpy(self.A, unit=unit)
+            return tr.tr2rpy(self.A, unit=unit, order=order)
         else:
-            return np.array([tr.tr2rpy(x, unit=unit) for x in self.A]).T
+            return np.array([tr.tr2rpy(x, unit=unit, order=order) for x in self.A]).T
+
+    def angvec(self, unit='rad'):
+        r"""
+        SO(3) or SE(3) as angle and rotation vector
+
+        :param unit: angular units: 'rad' [default], or 'deg'
+        :type unit: str
+        :param check: check that rotation matrix is valid
+        :type check: bool
+        :return: :math:`(\theta, {\bf v})`
+        :rtype: float, numpy.ndarray, shape=(3,)
+
+        ``q.angvec()`` is a tuple :math:`(\theta, v)` containing the rotation 
+        angle and a rotation axis which is equivalent to the rotation of
+        the unit quaternion ``q``.
+
+        By default the angle is in radians but can be changed setting `unit='deg'`.
+
+        Notes:
+
+        - If the input is SE(3) the translation component is ignored.
+
+        Example::
+
+        >>> UnitQuaternion.Rz(0.3).angvec()
+            (0.3, array([0., 0., 1.]))
+
+        :seealso: :func:`~spatialmath.quaternion.AngVec`, :func:`~angvec2r`
+        """
+        return tr.tr2angvec(self.R, unit=unit)
 
     def Ad(self):
         """
         Adjoint of SO(3)
-        
+
         :return: adjoint matrix
-        :rtype: numpy.ndarray, shape=(6,6)
-        
-        - ``SE3.Ad`` is the 6x6 adjoint matrix
-        
+        :rtype: numpy.ndarray, shape=(3,3)
+
+        - ``SEO.Ad`` is the 6x6 adjoint matrix
+
         :seealso: Twist.ad.
 
         """
-
-        return np.r_[ np.c_[self.R, tr.skew(self.t) @ self.R],
-                      np.c_[np.zeros((3,3)), self.R]
-                        ]
+        return np.array([
+            [self.R, tr.skew(self.t) @ self.R],
+            [np.zeros((3, 3)), self.R]
+            ])
 # ------------------------------------------------------------------------ #
 
     @staticmethod
@@ -237,12 +297,12 @@ class SO3(sp.SMPose):
 
         - ``SE3.Rx(theta)`` is an SO(3) rotation of ``theta`` radians about the x-axis
         - ``SE3.Rx(theta, "deg")`` as above but ``theta`` is in degrees
-        
+
         If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
         elements.
-        
+
         Example::
-            
+
             >>> x = SO3.Rx(np.linspace(0, math.pi, 20))
             >>> len(x)
             20
@@ -267,12 +327,12 @@ class SO3(sp.SMPose):
 
         - ``SO3.Ry(theta)`` is an SO(3) rotation of ``theta`` radians about the y-axis
         - ``SO3.Ry(theta, "deg")`` as above but ``theta`` is in degrees
-        
+
         If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
         elements.
 
         Example::
-            
+
             >>> x = SO3.Ry(np.linspace(0, math.pi, 20))
             >>> len(x)
             20
@@ -295,15 +355,15 @@ class SO3(sp.SMPose):
         :type unit: str
         :return: SO(3) rotation
         :rtype: SO3 instance
-        
+
         - ``SO3.Rz(theta)`` is an SO(3) rotation of ``theta`` radians about the z-axis
         - ``SO3.Rz(theta, "deg")`` as above but ``theta`` is in degrees
-        
+
         If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
         elements.
 
         Example::
-            
+
             >>> x = SE3.Rz(np.linspace(0, math.pi, 20))
             >>> len(x)
             20
@@ -325,9 +385,9 @@ class SO3(sp.SMPose):
 
         - ``SO3.Rand()`` is a random SO(3) rotation.
         - ``SO3.Rand(N)`` is a sequence of N random rotations.
-        
+
         Example::
-            
+
             >>> x = SO3.Rand()
             >>> x
             SO3(array([[ 0.1805082 , -0.97959019,  0.08842995],
@@ -336,7 +396,7 @@ class SO3(sp.SMPose):
 
         :seealso: :func:`spatialmath.quaternion.UnitQuaternion.Rand`
         """
-        return cls([tr.q2r(tr.rand()) for i in range(0, N)], check=False)
+        return cls([tr.q2r(tr.rand()) for _ in range(0, N)], check=False)
 
     @classmethod
     def Eul(cls, angles, *, unit='rad'):
@@ -352,16 +412,16 @@ class SO3(sp.SMPose):
 
         ``SO3.Eul(angles)`` is an SO(3) rotation defined by a 3-vector of Euler angles :math:`(\phi, \theta, \psi)` which
         correspond to consecutive rotations about the Z, Y, Z axes respectively.
-        
+
         If ``angles`` is an Nx3 matrix then the result is a sequence of rotations each defined by Euler angles
-        correponding to the rows of ``angles``.
+        corresponding to the rows of ``angles``.
 
         :seealso: :func:`~spatialmath.pose3d.SE3.eul`, :func:`~spatialmath.pose3d.SE3.Eul`, :func:`spatialmath.base.transforms3d.eul2r`
         """
         if argcheck.isvector(angles, 3):
-            return cls(tr.eul2r(angles, unit=unit))
+            return cls(tr.eul2r(angles, unit=unit), check=False)
         else:
-            return cls([tr.eul2r(a, unit=unit) for a in angles])
+            return cls([tr.eul2r(a, unit=unit) for a in angles], check=False)
 
     @classmethod
     def RPY(cls, angles, *, order='zyx', unit='rad'):
@@ -372,8 +432,8 @@ class SO3(sp.SMPose):
         :type angles: array_like or numpy.ndarray with shape=(N,3)
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
-        :param unit: rotation order: 'zyx' [default], 'xyz', or 'yxz'
-        :type unit: str
+        :param order: rotation order: 'zyx' [default], 'xyz', or 'yxz'
+        :type order: str
         :return: SO(3) rotation
         :rtype: SO3 instance
 
@@ -384,21 +444,21 @@ class SO3(sp.SMPose):
               then by roll about the new x-axis.  Convention for a mobile robot with x-axis forward
               and y-axis sideways.
             - 'xyz', rotate by yaw about the x-axis, then by pitch about the new y-axis,
-              then by roll about the new z-axis. Covention for a robot gripper with z-axis forward
+              then by roll about the new z-axis. Convention for a robot gripper with z-axis forward
               and y-axis between the gripper fingers.
             - 'yxz', rotate by yaw about the y-axis, then by pitch about the new x-axis,
               then by roll about the new z-axis. Convention for a camera with z-axis parallel
               to the optic axis and x-axis parallel to the pixel rows.
 
         If ``angles`` is an Nx3 matrix then the result is a sequence of rotations each defined by RPY angles
-        correponding to the rows of angles.
-        
+        corresponding to the rows of angles.
+
         :seealso: :func:`~spatialmath.pose3d.SE3.rpy`, :func:`~spatialmath.pose3d.SE3.RPY`, :func:`spatialmath.base.transforms3d.rpy2r`
         """
         if argcheck.isvector(angles, 3):
-                return cls(tr.rpy2r(angles, order=order, unit=unit))
+            return cls(tr.rpy2r(angles, order=order, unit=unit), check=False)
         else:
-            return cls([tr.rpy2r(a, order=order, unit=unit) for a in angles])
+            return cls([tr.rpy2r(a, order=order, unit=unit) for a in angles], check=False)
 
     @classmethod
     def OA(cls, o, a):
@@ -451,18 +511,16 @@ class SO3(sp.SMPose):
         :seealso: :func:`~spatialmath.pose3d.SE3.angvec`, :func:`spatialmath.base.transforms3d.angvec2r`
         """
         return cls(tr.angvec2r(theta, v, unit=unit), check=False)
-    
+
     @classmethod
     def Exp(cls, S, check=True, so3=True):
-        """
+        r"""
         Create an SO(3) rotation matrix from so(3)
 
         :param S: Lie algebra so(3)
         :type S: numpy ndarray
         :param check: check that passed matrix is valid so(3), default True
         :type check: bool
-        :param so3: input is an so(3) matrix (default True)
-        :type so3: bool
         :return: SO(3) rotation
         :rtype: SO3 instance
 
@@ -472,7 +530,7 @@ class SO3(sp.SMPose):
           vector (the unique elements of the so(3) skew-symmetric matrix)
         - ``SO3.Exp(T)`` is a sequence of SO(3) rotations defined by an Nx3 matrix
           of twist vectors, one per row.
-          
+
         Note:
         - if :math:`\theta \eq 0` the result in an identity matrix
         - an input 3x3 matrix is ambiguous, it could be the first or third case above.  In this
@@ -480,17 +538,26 @@ class SO3(sp.SMPose):
 
         :seealso: :func:`spatialmath.base.transforms3d.trexp`, :func:`spatialmath.base.transformsNd.skew`
         """
-        if argcheck.ismatrix(S, (-1,3)) and not so3:
-            return cls([tr.trexp(s, check=check) for s in S])
+        if argcheck.ismatrix(S, (-1, 3)) and not so3:
+            return cls([tr.trexp(s, check=check) for s in S], check=False)
         else:
             return cls(tr.trexp(S, check=check), check=False)
 
 
-
 # ============================== SE3 =====================================#
 
 
 class SE3(SO3):
+    """
+    SE(3) subclass
+
+    This subclass represents rigid-body motion in 3D space.  Internally it is a 
+    4x4 homogeneous transformation matrix belonging to the group SE(3).
+
+ .. inheritance-diagram:: spatialmath.pose3d.SE3
+    :top-classes: collections.UserList
+    :parts: 1
+    """
 
     def __init__(self, x=None, y=None, z=None, *, check=True):
         """
@@ -504,7 +571,7 @@ class SE3(SO3):
         :type z: float
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
-        
+
         - ``SE3()`` is a null motion -- the identity matrix
         - ``SE3(x, y, z)`` is a pure translation of (x,y,z)
         - ``SE3(T)`` where T is a 4x4 numpy array representing an SE(3) matrix.  If ``check``
@@ -521,21 +588,30 @@ class SE3(SO3):
             # empty constructor
             self.data = [np.eye(4)]
         elif y is not None and z is not None:
-                # SE3(x, y, z)
-                self.data = [tr.transl(x, y, z)]
+            # SE3(x, y, z)
+            self.data = [tr.transl(x, y, z)]
         elif y is None and z is None:
             if argcheck.isvector(x, 3):
                 # SE3( [x, y, z] )
                 self.data = [tr.transl(x)]
             elif isinstance(x, np.ndarray) and x.shape[1] == 3:
                 # SE3( Nx3 )
-                self.data = [tr.transl(T) for T in x]   
+                self.data = [tr.transl(T) for T in x]
             else:
-                super()._arghandler(x, check=check)
+                super().arghandler(x, check=check)
         else:
             raise ValueError('bad argument to constructor')
 
 # ------------------------------------------------------------------------ #
+    @property
+    def shape(self):
+        """
+        Shape of the object's interal matrix representation
+
+        :return: (4,4)
+        :rtype: tuple
+        """
+        return (4, 4)
 
     @property
     def t(self):
@@ -569,41 +645,44 @@ class SE3(SO3):
         Returns the inverse taking into account its structure
 
         :math:`T = \left[ \begin{array}{cc} R & t \\ 0 & 1 \end{array} \right], T^{-1} = \left[ \begin{array}{cc} R^T & -R^T t \\ 0 & 1 \end{array} \right]`
-        
+
         :seealso: :func:`~spatialmath.base.transform3d.trinv`
         """
         if len(self) == 1:
             return SE3(tr.trinv(self.A))
         else:
-            return SE3([tr.trinv(x) for x in self.A])
-    
+            return SE3([tr.trinv(x) for x in self.A], check=False)
+
     def delta(self, X2):
         r"""
-        Difference of SE(3)
+        Infinitesimal difference of SE(3)
 
-        :param X1: 
-        :type X1: SE3
+        :param X2:
+        :type X2: SE3
         :return: differential motion vector
         :rtype: numpy.ndarray, shape=(6,)
-            
-        - ``X1.delta(T2)`` is the differential motion (6x1) corresponding to 
-          infinitessimal motion (in the X1 frame) from pose X1 to X2.
-    
+
+        - ``X1.delta(X2)`` is the differential motion (6x1) corresponding to
+          infinitesimal motion (in the X1 frame) from pose X1 to X2.
+
         The vector :math:`d = [\delta_x, \delta_y, \delta_z, \theta_x, \theta_y, \theta_z`
-        represents infinitessimal translation and rotation.
-    
+        represents infinitesimal translation and rotation.
+
         Notes:
-            
+
         - the displacement is only an approximation to the motion T, and assumes
           that X1 ~ X2.
         - Can be considered as an approximation to the effect of spatial velocity over a
           a time interval, average spatial velocity multiplied by time.
-        
+
         Reference: Robotics, Vision & Control: Second Edition, P. Corke, Springer 2016; p67.
-        
+
         :seealso: :func:`~spatialmath.base.transform3d.tr2delta`
         """
-        return tr.tr2delta(self.A, X1.A)
+        return tr.tr2delta(self.A, X2.A)
+
+    def Twist3(self):
+        return sm.Twist3(self.log(twist=True))
 # ------------------------------------------------------------------------ #
 
     @staticmethod
@@ -637,11 +716,11 @@ class SE3(SO3):
 
         - ``SE3.Rx(THETA)`` is an SO(3) rotation of THETA radians about the x-axis
         - ``SE3.Rx(THETA, "deg")`` as above but THETA is in degrees
-        
+
         If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
         elements.
         """
-        return cls([tr.trotx(x, unit) for x in argcheck.getvector(theta)])
+        return cls([tr.trotx(x, unit) for x in argcheck.getvector(theta)], check=False)
 
     @classmethod
     def Ry(cls, theta, unit='rad'):
@@ -661,7 +740,7 @@ class SE3(SO3):
         If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
         elements.
         """
-        return cls([tr.troty(x, unit) for x in argcheck.getvector(theta)])
+        return cls([tr.troty(x, unit) for x in argcheck.getvector(theta)], check=False)
 
     @classmethod
     def Rz(cls, theta, unit='rad'):
@@ -677,14 +756,14 @@ class SE3(SO3):
 
         - ``SE3.Rz(THETA)`` is an SO(3) rotation of THETA radians about the z-axis
         - ``SE3.Rz(THETA, "deg")`` as above but THETA is in degrees
-        
+
         If ``theta`` is an array then the result is a sequence of rotations defined by consecutive
         elements.
         """
-        return cls([tr.trotz(x, unit) for x in argcheck.getvector(theta)])
+        return cls([tr.trotz(x, unit) for x in argcheck.getvector(theta)], check=False)
 
     @classmethod
-    def Rand(cls, *, xrange=[-1, 1], yrange=[-1, 1], zrange=[-1, 1], N=1):
+    def Rand(cls, *, xrange=(-1, 1), yrange=(-1, 1), zrange=(-1, 1), N=1):  # pylint: disable=arguments-differ
         """
         Create a random SE(3)
 
@@ -698,7 +777,7 @@ class SE3(SO3):
         :type N: int
         :return: homogeneous transformation matrix
         :rtype: SE3 instance
-        
+
         Return an SE3 instance with random rotation and translation.
 
         - ``SE3.Rand()`` is a random SE(3) translation.
@@ -711,11 +790,11 @@ class SE3(SO3):
         Y = np.random.uniform(low=yrange[0], high=yrange[1], size=N)  # random values in the range
         Z = np.random.uniform(low=yrange[0], high=zrange[1], size=N)  # random values in the range
         R = SO3.Rand(N=N)
-        return cls([tr.transl(x, y, z) @ tr.r2t(r.A) for (x, y, z, r) in zip(X, Y, Z, R)])
+        return cls([tr.transl(x, y, z) @ tr.r2t(r.A) for (x, y, z, r) in zip(X, Y, Z, R)], check=False)
 
     @classmethod
-    def Eul(cls, angles, unit='rad'):
-        """
+    def Eul(cls, angles, *, unit='rad'):
+        r"""
         Create an SE(3) pure rotation from Euler angles
 
         :param angles: 3-vector of Euler angles
@@ -727,19 +806,19 @@ class SE3(SO3):
 
         ``SE3.Eul(ANGLES)`` is an SO(3) rotation defined by a 3-vector of Euler angles :math:`(\phi, \theta, \psi)` which
         correspond to consecutive rotations about the Z, Y, Z axes respectively.
-        
+
         If ``angles`` is an Nx3 matrix then the result is a sequence of rotations each defined by Euler angles
-        correponding to the rows of angles.
+        corresponding to the rows of angles.
 
         :seealso: :func:`~spatialmath.pose3d.SE3.eul`, :func:`~spatialmath.pose3d.SE3.Eul`, :func:`spatialmath.base.transforms3d.eul2r`
         """
         if argcheck.isvector(angles, 3):
-            return cls(tr.eul2tr(angles, unit=unit))
+            return cls(tr.eul2tr(angles, unit=unit), check=False)
         else:
-            return cls([tr.eul2tr(a, unit=unit) for a in angles])
+            return cls([tr.eul2tr(a, unit=unit) for a in angles], check=False)
 
     @classmethod
-    def RPY(cls, angles, order='zyx', unit='rad'):
+    def RPY(cls, angles, *, order='zyx', unit='rad'):
         """
         Create an SO(3) pure rotation from roll-pitch-yaw angles
 
@@ -747,8 +826,8 @@ class SE3(SO3):
         :type angles: array_like or numpy.ndarray with shape=(N,3)
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
-        :param unit: rotation order: 'zyx' [default], 'xyz', or 'yxz'
-        :type unit: str
+        :param order: rotation order: 'zyx' [default], 'xyz', or 'yxz'
+        :type order: str
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
 
@@ -759,21 +838,21 @@ class SE3(SO3):
               then by roll about the new x-axis.  Convention for a mobile robot with x-axis forward
               and y-axis sideways.
             - 'xyz', rotate by yaw about the x-axis, then by pitch about the new y-axis,
-              then by roll about the new z-axis. Covention for a robot gripper with z-axis forward
+              then by roll about the new z-axis. Convention for a robot gripper with z-axis forward
               and y-axis between the gripper fingers.
             - 'yxz', rotate by yaw about the y-axis, then by pitch about the new x-axis,
               then by roll about the new z-axis. Convention for a camera with z-axis parallel
               to the optic axis and x-axis parallel to the pixel rows.
-              
+
         If ``angles`` is an Nx3 matrix then the result is a sequence of rotations each defined by RPY angles
-        correponding to the rows of angles.
+        corresponding to the rows of angles.
 
         :seealso: :func:`~spatialmath.pose3d.SE3.rpy`, :func:`~spatialmath.pose3d.SE3.RPY`, :func:`spatialmath.base.transforms3d.rpy2r`
         """
         if argcheck.isvector(angles, 3):
-                return cls(tr.rpy2tr(angles, order=order, unit=unit))
+            return cls(tr.rpy2tr(angles, order=order, unit=unit), check=False)
         else:
-            return cls([tr.rpy2tr(a, order=order, unit=unit) for a in angles])
+            return cls([tr.rpy2tr(a, order=order, unit=unit) for a in angles], check=False)
 
     @classmethod
     def OA(cls, o, a):
@@ -802,7 +881,7 @@ class SE3(SO3):
 
         :seealso: :func:`spatialmath.base.transforms3d.oa2r`
         """
-        return cls(tr.oa2tr(o, a))
+        return cls(tr.oa2tr(o, a), check=False)
 
     @classmethod
     def AngVec(cls, theta, v, *, unit='rad'):
@@ -828,10 +907,10 @@ class SE3(SO3):
 
         :seealso: :func:`~spatialmath.pose3d.SE3.angvec`, :func:`spatialmath.base.transforms3d.angvec2r`
         """
-        return cls(tr.angvec2tr(theta, v, unit=unit))
+        return cls(tr.angvec2tr(theta, v, unit=unit), check=False)
 
     @classmethod
-    def Exp(cls, S):
+    def Exp(cls, S, check=True):
         """
         Create an SE(3) rotation matrix from se(3)
 
@@ -841,84 +920,83 @@ class SE3(SO3):
         :rtype: SO3 instance
 
         - ``SE3.Exp(S)`` is an SE(3) rotation defined by its Lie algebra
-          which is a 3x3 se(3) matrix (skew symmetric)
+          which is a 4x4 se(3) matrix (skew symmetric)
         - ``SE3.Exp(t)`` is an SE(3) rotation defined by a 6-element twist
           vector (the unique elements of the se(3) skew-symmetric matrix)
 
         :seealso: :func:`spatialmath.base.transforms3d.trexp`, :func:`spatialmath.base.transformsNd.skew`
         """
-        if isinstance(S, np.ndarray) and S.shape[1] == 6:
-            return cls([tr.trexp(s) for s in S])
+        if isinstance(S, list):
+            return cls([tr.exp(s) for s in S], check=False)
         else:
             return cls(tr.trexp(S), check=False)
-    
+
     @classmethod
     def Tx(cls, x):
         """
         Create SE(3) translation along the X-axis
 
-        :param theta: translation distance along the X-axis
-        :type theta: float
+        :param x: translation distance along the X-axis
+        :type x: float
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
 
         `SE3.Tz(D)`` is an SE(3) translation of D along the x-axis
         """
-        return cls(tr.transl(x, 0, 0))
+        return cls(tr.transl(x, 0, 0), check=False)
 
     @classmethod
     def Ty(cls, y):
         """
         Create SE(3) translation along the Y-axis
 
-        :param theta: translation distance along the Y-axis
-        :type theta: float
+        :param y: translation distance along the Y-axis
+        :type y: float
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
 
         `SE3.Tz(D)`` is an SE(3) translation of D along the y-axis
         """
-        return cls(tr.transl(0, y, 0))
+        return cls(tr.transl(0, y, 0), check=False)
 
     @classmethod
     def Tz(cls, z):
         """
         Create SE(3) translation along the Z-axis
 
-        :param theta: translation distance along the Z-axis
-        :type theta: float
+        :param z: translation distance along the Z-axis
+        :type z: float
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
 
         `SE3.Tz(D)`` is an SE(3) translation of D along the z-axis
         """
-        return cls(tr.transl(0, 0, z))
-    
+        return cls(tr.transl(0, 0, z), check=False)
+
     @classmethod
     def Delta(cls, d):
         r"""
-        Create SE(3) from diffential motion
+        Create SE(3) from differential motion
 
         :param d: differential motion
         :type d: 6-element array_like
         :return: 4x4 homogeneous transformation matrix
         :rtype: SE3 instance
-            
+
 
         - ``T = delta2tr(d)`` is an SE(3) representing differential 
           motion :math:`d = [\delta_x, \delta_y, \delta_z, \theta_x, \theta_y, \theta_z`.
-    
+
         Reference: Robotics, Vision & Control: Second Edition, P. Corke, Springer 2016; p67.
-        
+
         :seealso: :func:`~delta`, :func:`~spatialmath.base.transform3d.delta2tr`
 
         """
-        return tr.tr2delta(self.A, X1.A)
+        return tr.tr2delta(d)
+
 
-            
 if __name__ == '__main__':   # pragma: no cover
 
     import pathlib
-    import os.path
 
-    exec(open(os.path.join(pathlib.Path(__file__).parent.absolute(), "test_pose3d.py")).read())
+    exec(open(pathlib.Path(__file__).parent.absolute() / "test_pose3d.py").read())  # pylint: disable=exec-used
